@@ -1,7 +1,7 @@
 from functools import update_wrapper
 from typing import Type
 
-from .registry import register_deserializer, register_serializer
+from .registry import register_deserializer, register_serializer, deserialize
 from .signatures import Serializer, Deserializer
 
 # pylint: disable=invalid-name,redefined-builtin
@@ -19,12 +19,17 @@ def serializer(type: Type):
 
 def deserializer(type: Type):
     '''Decorator that registers a function as a deserializer for a type.
+    The decorated function receives a `deserialize` method that takes a single
+    argument - the data to deserialize to `type`.
 
     See:`examples.simple`
     '''
     def wrapper(func: Deserializer):
         update_wrapper(wrapper, func)
         register_deserializer(type, func)
+        def ds(data_dict) -> type:
+            return deserialize(type, data_dict)
+        setattr(func, 'deserialize', ds)
         return func
     return wrapper
 
